@@ -4,6 +4,7 @@
  * Copyright (C) 2007 Vincent Untz.
  * Copyright (C) 2008 Lucas Rocha.
  * Copyright (C) 2008 William Jon McCann <jmccann@redhat.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -482,6 +483,64 @@ on_save_session_clicked (GtkWidget           *widget,
         g_debug ("Session saving is not implemented yet!");
 }
 
+static gboolean
+on_main_notebook_scroll_event (GtkWidget        *widget,
+                               GdkEventScroll   *event)
+{
+        GtkNotebook *notebook = GTK_NOTEBOOK (widget);
+        GtkWidget *child, *event_widget, *action_widget;
+
+        child = gtk_notebook_get_nth_page (notebook, gtk_notebook_get_current_page (notebook));
+        if (child == NULL)
+                return FALSE;
+
+        event_widget = gtk_get_event_widget ((GdkEvent*) event);
+
+        /* Ignore scroll events from the content of the page */
+        if (event_widget == NULL || event_widget == child || gtk_widget_is_ancestor (event_widget, child))
+                return FALSE;
+
+        /* And also from the action widgets */
+        action_widget = gtk_notebook_get_action_widget (notebook, GTK_PACK_START);
+        if (event_widget == action_widget || (action_widget != NULL && gtk_widget_is_ancestor (event_widget, action_widget)))
+                return FALSE;
+
+        action_widget = gtk_notebook_get_action_widget (notebook, GTK_PACK_END);
+        if (event_widget == action_widget || (action_widget != NULL && gtk_widget_is_ancestor (event_widget, action_widget)))
+                return FALSE;
+
+        switch (event->direction) {
+                case GDK_SCROLL_RIGHT:
+                case GDK_SCROLL_DOWN:
+                        gtk_notebook_next_page (notebook);
+                        break;
+                case GDK_SCROLL_LEFT:
+                case GDK_SCROLL_UP:
+                        gtk_notebook_prev_page (notebook);
+                        break;
+                case GDK_SCROLL_SMOOTH:
+                        switch (gtk_notebook_get_tab_pos (notebook)) {
+                                case GTK_POS_LEFT:
+                                case GTK_POS_RIGHT:
+                                        if (event->delta_y > 0)
+                                                gtk_notebook_next_page (notebook);
+                                        else if (event->delta_y < 0)
+                                                gtk_notebook_prev_page (notebook);
+                                        break;
+                                case GTK_POS_TOP:
+                                case GTK_POS_BOTTOM:
+                                        if (event->delta_x > 0)
+                                                gtk_notebook_next_page (notebook);
+                                        else if (event->delta_x < 0)
+                                                gtk_notebook_prev_page (notebook);
+                                        break;
+                        }
+                        break;
+        }
+
+        return TRUE;
+}
+
 static gboolean
 visible_func (GtkTreeModel *model,
               GtkTreeIter  *iter,
@@ -790,6 +849,13 @@ gsm_properties_dialog_init (GsmPropertiesDialog *dialog)
         content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
         widget = GTK_WIDGET (gtk_builder_get_object (dialog->xml,
                                                      "main-notebook"));
+
+        gtk_widget_add_events (widget, GDK_SCROLL_MASK);
+        g_signal_connect (widget,
+                          "scroll-event",
+                          G_CALLBACK (on_main_notebook_scroll_event),
+                          NULL);
+
         gtk_box_pack_start (GTK_BOX (content_area), widget, TRUE, TRUE, 0);
 
         gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
